util

package module
v0.0.0-...-0ba627c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DelayedCancel

func DelayedCancel(ctx context.Context, delay time.Duration) (context.Context, context.CancelFunc)

DelayedCancel returns a context that gets canceled after a delay when its parent context is canceled. The returned context.CancelFunc immediately cancels the context and should be used like context.WithCancel's one.

func Sleep

func Sleep(ctx context.Context, d time.Duration)

Types

This section is empty.

Directories

Path Synopsis
Package bsize provides typed bytes/size handling and parsing, modeled after time.Duration.
Package bsize provides typed bytes/size handling and parsing, modeled after time.Duration.
internal/ddlog
Package ddlog generates log attributes for Datadog's standard attributes: https://docs.datadoghq.com/standard-attributes/?product=log
Package ddlog generates log attributes for Datadog's standard attributes: https://docs.datadoghq.com/standard-attributes/?product=log

Jump to